@@ -2,6 +2,7 @@ from __future__ import unicode_literals, division, absolute_import
 import logging
 from flexget.plugin import register_plugin, DependencyError
 from flexget.utils import imdb
+from flexget.utils.log import log_once
 
 try:
     # TODO: Fix this after api_tmdb has module level functions
@@ -55,8 +56,8 @@ class PluginTmdbLookup(object):
                            tmdb_id=entry.get('tmdb_id', eval_lazy=False),
                            imdb_id=imdb_id)
             entry.update_using_map(self.field_map, movie)
-        except LookupError as e:
-            log.info(u'Tmdb lookup failed for %s (%s)' % (entry['title'], e.message))
+        except LookupError:
+            log_once('TMDB lookup failed for %s' % entry['title'], log, logging.WARN)
             # Set all of our fields to None if the lookup failed
             entry.unregister_lazy_fields(self.field_map, self.lazy_loader)
         return entry[field]
